Changelog
=========

0.0.2 (2022-05-10)
------------------

- fixed error in plain text output of `pic-info`
- added `pic-predict-redis` console script (`pic/predict_redis.py`) for making predictions via Redis


0.0.1 (2021-01-11)
------------------

- initial release
